@@ -3,6 +3,8 @@
  */
 package org.gcube.portlets.user.tdwx.client.model.grid;
 
+import java.util.Date;
+
 import org.gcube.portlets.user.tdwx.shared.model.ColumnDefinition;
 import org.gcube.portlets.user.tdwx.shared.model.DataRow;
 
@@ -12,17 +14,18 @@ import com.sencha.gxt.widget.core.client.grid.ColumnConfig;
 
 /**
  * 
- * @author "Giancarlo Panichi" 
- * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
- *
+ * @author "Giancarlo Panichi" <a
+ *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * 
  * @param <N>
  */
 public class DataRowColumnConfig<N> extends ColumnConfig<DataRow, N> {
-
-	protected ColumnDefinition definition;
 	
+	protected ColumnDefinition definition;
+
 	public DataRowColumnConfig(ColumnDefinition definition) {
-		super(new DataRowValueProvider<N>(definition.getKey()), definition.getWidth(), definition.getLabel());
+		super(new DataRowValueProvider<N>(definition.getKey()), definition
+				.getWidth(), definition.getLabel());
 		this.definition = definition;
 	}
 
@@ -35,11 +38,19 @@ public class DataRowColumnConfig<N> extends ColumnConfig<DataRow, N> {
 
 	@SuppressWarnings("unchecked")
 	public void setCell(AbstractCell<Boolean> cell) {
-	    Cell<N> cell2 = (Cell<N>) cell;
+		Cell<N> cell2 = (Cell<N>) cell;
+		super.setCell(cell2);
+	}
+	
+	@SuppressWarnings("unchecked")
+	public void setCellDate(AbstractCell<Date> cell) {
+		Cell<N> cell2 = (Cell<N>) cell;
 		super.setCell(cell2);
 	}
 	
 	public Cell<N> getCell() {
-	    return super.getCell();
+		return super.getCell();
 	}
+
+	
 }
